@@ -586,12 +586,33 @@ CHIPSET(0x7340, 0x7340, NAVI14)
 CHIPSET(0x7341, 0x7341, NAVI14)
 CHIPSET(0x7347, 0x7347, NAVI14)
 CHIPSET(0x734F, 0x734F, NAVI14)
+CHIPSET(0x15E7, 0x15E7, RENOIR)
 CHIPSET(0x1636, 0x1636, RENOIR)
+CHIPSET(0x1638, 0x1638, RENOIR)
+CHIPSET(0x164C, 0x164C, RENOIR)
 CHIPSET(0x7360, 0x7360, NAVI12)
 CHIPSET(0x7362, 0x7362, NAVI12)
 CHIPSET(0x73A0, 0x73A0, SIENNA_CICHLID)
+CHIPSET(0x73A1, 0x73A1, SIENNA_CICHLID)
 CHIPSET(0x73A2, 0x73A2, SIENNA_CICHLID)
 CHIPSET(0x73A3, 0x73A3, SIENNA_CICHLID)
 CHIPSET(0x73AB, 0x73AB, SIENNA_CICHLID)
 CHIPSET(0x73AE, 0x73AE, SIENNA_CICHLID)
+CHIPSET(0x73AF, 0x73AF, SIENNA_CICHLID)
 CHIPSET(0x73BF, 0x73BF, SIENNA_CICHLID)
+CHIPSET(0x163F, 0x163F, VANGOGH)
+CHIPSET(0x164D, 0x164D, YELLOW_CARP)
+CHIPSET(0x1681, 0x1681, YELLOW_CARP)
+CHIPSET(0x73C0, 0x73C0, NAVY_FLOUNDER)
+CHIPSET(0x73C1, 0x73C1, NAVY_FLOUNDER)
+CHIPSET(0x73C3, 0x73C3, NAVY_FLOUNDER)
+CHIPSET(0x73DF, 0x73DF, NAVY_FLOUNDER)
+CHIPSET(0x73E0, 0x73E0, DIMGREY_CAVEFISH)
+CHIPSET(0x73E1, 0x73E1, DIMGREY_CAVEFISH)
+CHIPSET(0x73E2, 0x73E2, DIMGREY_CAVEFISH)
+CHIPSET(0x73E3, 0x73E3, DIMGREY_CAVEFISH)
+CHIPSET(0x73FF, 0x73FF, DIMGREY_CAVEFISH)
+CHIPSET(0x7408, 0x7408, ALDEBARAN)
+CHIPSET(0x740C, 0x740C, ALDEBARAN)
+CHIPSET(0x740F, 0x740F, ALDEBARAN)
+CHIPSET(0x7410, 0x7410, ALDEBARAN)
